Temboard 7.9 : Support for PostgreSQL 14
================================================================================

Paris, France, Jan. 3rd 2022

`Temboard` is a graphic tool that helps users monitor, optimize and configure
multiple PostgreSQL instances.

It is composed of 2 basic elements:

* A lightweight agent installe on each PostgreSQL instance
* A central server to control the agents and collect metrics

We're releasing today the version 7.9 which is minor release containing
bugfixes and non-breaking changes.


Support for PostgreSQL 14 and other improvements
------------------------------------------------------------------------------

This new version bring a few improvements including the support for PostgreSQL
14, some UI glitches, a handful of monitoring fixes and a important
restructuration of the project documentation.


Links
-------------------------------------------------------------------------------

* [Quickstart](https://temboard.readthedocs.io/en/master/QUICKSTART/)
* [Install Guide](https://temboard.readthedocs.io/en/master/server_install/)
* [Upgrade](https://temboard.readthedocs.io/en/master/server_upgrade/)


Thanks
--------------------------------------------------------------------------------

This release includes code, bugfixes, feedback and ideas from multiple
contributors: @Zig3tPuce, @bsislow, @wsescu, @dgffin.

Many thanks to them!


How to contribute
--------------------------------------------------------------------------------

Temboard is part of the [Dalibo Labs] initiative.

This is an open project, contributions are welcome. We need your feedback and
ideas! Let us know what you think of this tool, how it fits your needs and
what features are missing.
